from distutils.core import setup

setup(
    name            = 'xshg',
    version         = '1.0.0',
    py_modules      = ['xshg'],
    author          = 'xshg',
    author_email    = 'xshg@hotmail.com',
    url             = 'http://www.luckya2z.com',
    description     = 'samples from xshg',
    )
